@@ -195,6 +195,9 @@ class Variable(VariableInterface):
     # указанной переменной
     alias = ""
 
+    On = "on"
+    Off = "off"
+
     def __init__(self, parent=None, **kwargs):
         """
         Initialize instance
