@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -15,8 +15,11 @@
 #  limitations under the License.
 
 import re
-from xml import xpath
-from calculate.lib.cl_template import objShare, blocText, xmlDoc
+from calculate.lib.cl_xml import xpath
+from generic import objShare
+from calculate.lib.cl_template import blocText
+from calculate.lib.cl_xml import xmlDoc
+
 
 class samba(objShare):
     """Класс для обработки конфигурационного файла типа samba
@@ -25,17 +28,20 @@ class samba(objShare):
     _comment = "#"
     configName = "samba"
     configVersion = "0.1"
-    reHeader = re.compile("^[\t ]*\[[^\[\]]+\].*\n",re.M)
-    reBody = re.compile(".+",re.M|re.S)
-    reComment = re.compile("\s*%s.*|\s*;.*"%(_comment))
+    reHeader = re.compile("^[\t ]*\[[^\[\]]+\].*\n", re.M)
+    reBody = re.compile(".+", re.M | re.S)
+    reComment = re.compile("\s*%s.*|\s*;.*" % _comment)
     reSeparator = re.compile("\s*=\s*")
     sepFields = "\n"
     reSepFields = re.compile(sepFields)
 
-    def __init__(self,text):
+    def __init__(self, text):
         self.text = text
+        self.prepare()
+
+    def prepare(self):
         self.blocTextObj = blocText()
-        self._splitToFields =  self.splitToFields
+        self._splitToFields = self.splitToFields
         # Объект документ
         self.docObj = self._textToXML()
         # XML документ
@@ -58,39 +64,33 @@ class samba(objShare):
         xmlAreas = xpath.Evaluate("child::area", self.docObj.body)
         xmlArea = None
         for xmlArea in xmlAreas:
-            firstArea = False
             xmlFields = xpath.Evaluate("child::field", xmlArea)
-            if not (xmlFields and\
-                (self.docObj.getTypeField(xmlFields[-1]) == "br" or\
+            if not (xmlFields and (
+                self.docObj.getTypeField(xmlFields[-1]) == "br" or
                     self.docObj.getTypeField(xmlFields[-1]) == "comment")):
                 if xmlArea.nextSibling:
                     parentNode = xmlArea.parentNode
                     nextNode = xmlArea.nextSibling
-                    parentNode.insertBefore(self.docObj.createField("br",
-                                                            [],"",[],
-                                                            False,False),
-                                                            nextNode)
+                    parentNode.insertBefore(self.docObj.createField(
+                        "br", [], "", [], False, False), nextNode)
             # Добавление переводов строк между полями
             if xmlFields:
                 for node in xmlFields:
                     # Добавление перевода строк в если его нет между полями
-                    if self.docObj.getTypeField(node) == "var" and\
-                        node.previousSibling and\
-                        not (self.docObj.getTypeField(node.previousSibling) in\
-                             ("br","comment")):
-                        xmlArea.insertBefore(self.docObj.createField("br",
-                                                                     [],"",[],
-                                                                     False,
-                                                                     False),
-                                             node)
+                    if (self.docObj.getTypeField(node) == "var" and
+                            node.previousSibling and
+                            not (self.docObj.getTypeField(
+                                node.previousSibling) in ("br", "comment"))):
+                        xmlArea.insertBefore(self.docObj.createField(
+                            "br", [], "", [], False, False), node)
 
         # Удаление лишних переводов строк
         childNodes = self.docObj.getFieldsArea(self.docObj.body)
         lenBr = 0
         removeBrNodes = []
         for node in childNodes:
-            if node.tagName == "field" and\
-                self.docObj.getTypeField(node) == "br":
+            if (node.tagName == "field" and
+                    self.docObj.getTypeField(node) == "br"):
                 lenBr += 1
                 if lenBr > 2:
                     removeBrNodes.append(node)
@@ -98,15 +98,15 @@ class samba(objShare):
                 lenBr = 0
         # Удаление
         for rmNode in removeBrNodes:
-           self.docObj.body.removeChild(rmNode)
+            self.docObj.body.removeChild(rmNode)
 
         # Если после есть BR а за ним ничего нет, удаляем BR
         if xmlArea:
-            if xmlArea.nextSibling and\
-                self.docObj.getTypeField(xmlArea.nextSibling) == "br":
-                    if not xmlArea.nextSibling.nextSibling:
-                        parentNode = xmlArea.nextSibling.parentNode
-                        parentNode.removeChild(xmlArea.nextSibling)
+            if (xmlArea.nextSibling and
+                    self.docObj.getTypeField(xmlArea.nextSibling) == "br"):
+                if not xmlArea.nextSibling.nextSibling:
+                    parentNode = xmlArea.nextSibling.parentNode
+                    parentNode.removeChild(xmlArea.nextSibling)
 
     def join(self, sambaObj):
         """Объединяем конфигурации"""
@@ -116,12 +116,14 @@ class samba(objShare):
 
     def setDataField(self, txtLines, endtxtLines):
         """Создаем список объектов с переменными"""
+
         class fieldData:
             def __init__(self):
                 self.name = False
                 self.value = False
                 self.comment = False
                 self.br = False
+
         fields = []
         field = fieldData()
         z = 0
@@ -142,22 +144,20 @@ class samba(objShare):
                 nameValue = self.reSeparator.split(pars)
                 if len(nameValue) > 2:
                     valueList = nameValue[1:]
-                    nameValue =[nameValue[0],"=".join(valueList)]
+                    nameValue = [nameValue[0], "=".join(valueList)]
                 if len(nameValue) == 2:
                     name = nameValue[0]
-                    value = nameValue[1].replace(self.sepFields,"")
-                    field.name = name.replace(" ","").replace("\t","")
+                    value = nameValue[1].replace(self.sepFields, "")
+                    field.name = name.replace(" ", "").replace("\t", "")
                     field.value = value
                     field.br = textLine
                     fields.append(field)
                     field = fieldData()
         return fields
 
-
     def splitCleanBloc(self, txtBloc):
         """Делим блок на две части (переменные, пустые строки в конце)"""
         txtLines = txtBloc.split("\n")
-        firstBloc = []
         nextBloc = []
         txtLines.reverse()
         z = 0
@@ -173,7 +173,7 @@ class samba(objShare):
         if nextBloc:
             firstBloc.append("")
         if nextBloc and "\n".join(nextBloc):
-            return ("\n".join(firstBloc), "\n".join(nextBloc))
+            return "\n".join(firstBloc), "\n".join(nextBloc)
         else:
             return False
 
@@ -198,7 +198,7 @@ class samba(objShare):
             else:
                 headsAreas.append(blocs[0][i])
                 bodyAreas.append(blocs[1][i])
-        return (headsAreas, bodyAreas)
+        return headsAreas, bodyAreas
 
     def createTxtConfig(self, strHeader, dictVar):
         """Cоздает область с заголовком
@@ -210,12 +210,12 @@ class samba(objShare):
             return ""
         outTxt = "[" + strHeader + "]\n"
         for key in dictVar.keys():
-            outTxt += "%s = %s\n" %(key,dictVar[key])
+            outTxt += "%s = %s\n" % (key, dictVar[key])
         return outTxt
 
     def _textToXML(self):
         """Преобразует текст в XML"""
-        blTmp = self.blocTextObj.findBloc(self.text,self.reHeader,self.reBody)
+        blTmp = self.blocTextObj.findBloc(self.text, self.reHeader, self.reBody)
         blocs = self.getFullAreas(blTmp)
         headers = []
         startHeaders = []
@@ -238,7 +238,7 @@ class samba(objShare):
                 finHeaders.append(listfinH[1])
             else:
                 finHeaders.append("")
-            headers.append(finH.replace("[","").replace("]","").strip())
+            headers.append(finH.replace("[", "").replace("]", "").strip())
         bodys = blocs[1]
 
         z = 0
@@ -249,46 +249,46 @@ class samba(objShare):
             areaAction = False
             if h:
                 if h[0] == "!":
-                    docObj.createCaption(h[1:], [startHeaders[z],""])
+                    docObj.createCaption(h[1:], [startHeaders[z], ""])
                     areaAction = "drop"
                 elif h[0] == "-":
-                    docObj.createCaption(h[1:], [startHeaders[z],""])
+                    docObj.createCaption(h[1:], [startHeaders[z], ""])
                     areaAction = "replace"
                 else:
-                    docObj.createCaption(h, [startHeaders[z],""])
+                    docObj.createCaption(h, [startHeaders[z], ""])
             else:
-                docObj.createCaption(h, [startHeaders[z],""])
+                docObj.createCaption(h, [startHeaders[z], ""])
 
             if "\n" in blocs[0][z]:
                 if self.reComment.search(finHeaders[z]):
-                        docObj.createField('comment', [finHeaders[z]])
-                elif not finHeaders[z].strip() and\
-                     finHeaders[z].replace("\n",""):
-                        docObj.createField('br',
-                                            [finHeaders[z].replace("\n","")])
+                    docObj.createField('comment', [finHeaders[z]])
+                elif not finHeaders[z].strip() and \
+                        finHeaders[z].replace("\n", ""):
+                    docObj.createField('br',
+                                       [finHeaders[z].replace("\n", "")])
                 else:
                     docObj.createField('br')
             fields = self._splitToFields(bodys[z])
             for f in fields:
-                if f.name != False and f.value!=False and f.br!=False:
+                if (f.name is not False and
+                        f.value is not False and f.br is not False):
                     # Обработка условий для samba
-                    if f.name[0] == "!" or f.name[0] == "-" or\
-                        f.name[0] == "+":
+                    if (f.name[0] == "!" or
+                            f.name[0] == "-" or f.name[0] == "+"):
                         qns = self.removeSymbolTerm(f.br)
-                        xmlField = docObj.createField("var",
-                                                  [qns],
-                                                  f.name[1:], [f.value])
+                        xmlField = docObj.createField(
+                            "var", [qns], f.name[1:], [f.value])
                         if f.name[0] == "!":
                             # Удаляемое в дальнейшем поле
                             docObj.setActionField(xmlField, "drop")
                     else:
-                        docObj.createField("var",[f.br.replace("\n","")],
+                        docObj.createField("var", [f.br.replace("\n", "")],
                                            f.name, [f.value])
                     docObj.createField('br')
-                elif f.comment != False:
+                elif f.comment is not False:
                     docObj.createField('comment', [f.comment])
-                elif f.br != False:
-                    docObj.createField('br', [f.br.replace("\n","")])
+                elif f.br is not False:
+                    docObj.createField('br', [f.br.replace("\n", "")])
             if h.strip():
                 area = docObj.createArea()
                 if areaAction:
@@ -301,4 +301,3 @@ class samba(objShare):
                 docObj.clearTmpFields()
             z += 1
         return docObj
- 
