@@ -18,7 +18,7 @@ from os import path
 import os
 from calculate.lib.datavars import ReadonlyVariable
 from calculate.lib.utils.common import (getValueFromCmdLine,
-                                        getValueFromConfig)
+                                        getValueFromConfig, CmdlineParams)
 from collections import OrderedDict
 
 import sys
@@ -447,7 +447,8 @@ class VariableOsClockTimezone(ReadonlyVariable):
         zoneinfodir = "/usr/share/zoneinfo/"
         timezonefile = "/etc/timezone"
         # try get timezone from kernel calculate param
-        timezone = getValueFromCmdLine("calculate", 2)
+        timezone = getValueFromCmdLine(
+            CmdlineParams.Calculate, CmdlineParams.Timezone)
         if timezone and \
                 path.exists(path.join(zoneinfodir, timezone)):
             return timezone
@@ -461,16 +462,18 @@ class VariableOsLocaleLocale(ReadonlyVariable, Locale):
     """
     Locale (example: ru_RU.UTF-8)
     """
+    env_var = "LANG"
 
     def get(self):
         # get locale from boot calculate param
         locale_file = '/etc/env.d/02locale'
-        locale_val = getValueFromCmdLine("calculate", 0)
+        locale_val = getValueFromCmdLine(
+            CmdlineParams.Calculate, CmdlineParams.Locale)
         if self.isLangExists(locale_val):
             cmd_val = self.getFieldByLang('locale', locale_val)
         else:
             cmd_val = None
-        locale_val = getValueFromConfig(locale_file, 'LANG')
+        locale_val = getValueFromConfig(locale_file, self.env_var)
         if self.isValueInFieldExists('locale', locale_val):
             file_val = locale_val
         else:
@@ -480,8 +483,8 @@ class VariableOsLocaleLocale(ReadonlyVariable, Locale):
                 return cmd_val or file_val
             else:
                 return file_val or cmd_val
-        if "LANG" in os.environ and os.environ["LANG"] != "C":
-            return os.environ["LANG"]
+        if self.env_var in os.environ and os.environ[self.env_var] != "C":
+            return os.environ[self.env_var]
         return self.getFieldByLang("locale", "default")
 
 
@@ -537,9 +540,9 @@ class VariableOsLocaleLatSet(ReadonlyVariable, Locale):
         """xkb layouts (example: en,ru)"""
         layout = self.Get('os_locale_xkbname').split(',')
         if len(layout) == 1:
-            return "on"
+            return self.On
         else:
-            return "off"
+            return self.Off
 
 
 class VariableOsLang(ReadonlyVariable, Locale):
